pub struct AtomicDecisionCube {
dt_len: usize,
e_len: usize,
s_len: usize,
decisions: Box<[AtomicDecision]>,
}Expand description
A flattened 3D data structure to manage atomic decisions for multiple dimensions with good cache performance.
Fields
dt_len: usizeLength of the time dimension.
e_len: usizeLength of the energy dimension.
s_len: usizeLength of the state dimension.
decisions: Box<[AtomicDecision]>Array of atomic decisions.
Implementations
Sourceimpl AtomicDecisionCube
impl AtomicDecisionCube
Sourcepub fn new(dt_len: usize, e_len: usize, s_len: usize) -> Self
pub fn new(dt_len: usize, e_len: usize, s_len: usize) -> Self
Creates a new AtomicDecisionCube with the specified dimensions and initializes all decisions to StayInCharge.
Arguments
dt_len- The length of the time dimension.e_len- The length of the energy dimension.s_len- The length of the state dimension.
Returns
A new instance of AtomicDecisionCube.
Sourcepub fn get(&self, dt: usize, e: usize, s: usize) -> AtomicDecision
pub fn get(&self, dt: usize, e: usize, s: usize) -> AtomicDecision
Retrieves the atomic decision at the specified indices.
Arguments
dt- The index along the time dimension.e- The index along the energy dimension.s- The index along the state dimension.
Returns
The AtomicDecision at the specified indices.
Sourcepub fn set(&mut self, dt: usize, e: usize, s: usize, decision: AtomicDecision)
pub fn set(&mut self, dt: usize, e: usize, s: usize, decision: AtomicDecision)
Sets the atomic decision at the specified indices.
Arguments
dt- The index along the time dimension.e- The index along the energy dimension.s- The index along the state dimension.decision- TheAtomicDecisionto set at the specified indices.